from distutils.core import setup

setup (
    name = 'spinklepypi',
    version = '1.0.0',
    py_modules = ['nester'],
    author = 'cbpython',
    author_email = 'sdkjson@hotmail.com',
    url = 'http://whatever.com',
    description = 'annpying nester list thing',
    )
    
